@@ -41,7 +41,7 @@ def apply_imported_packages(account_id: str, env_id: str, resources: List, on_st
 
     with tempfile.NamedTemporaryFile() as f:
         my_env = os.environ.copy()
-        process = subprocess.Popen(["cdktf", "plan" if plan else "deploy", env_id, "--auto-approve", 
+        process = subprocess.Popen([shutil.which("cdktf"), "plan" if plan else "deploy", env_id, "--auto-approve", 
                                     "--app", app_command,
                                     '--outputs-file', output_file_name,
                                     '--output', output_dir or '.',
@@ -81,7 +81,7 @@ def delete_imported_packages(account_id: str, env_id: str, resources: List, outp
     
     with tempfile.NamedTemporaryFile() as f:
         my_env = os.environ.copy()
-        process = subprocess.Popen(["cdktf", "destroy", env_id, "--auto-approve", 
+        process = subprocess.Popen([shutil.which("cdktf"), "destroy", env_id, "--auto-approve", 
                                     '--output', output_dir or '.',
                                     "--app", app_command], stdout=subprocess.PIPE, env=my_env)
         for c in iter(lambda: process.stdout.read(1), b''):
